@@ -7,9 +7,9 @@ from .data import *
 from .progress import ProgressBar
 
 
-def plot_sim(sim):
+def plot_sim(sim, lattice):
     points = o3d.geometry.PointCloud()
-    points.points = o3d.utility.Vector3dVector(np.asarray([np.dot(fcc_transform(), p[1:])
+    points.points = o3d.utility.Vector3dVector(np.asarray([np.dot(lattice, p[1:])
                                                            for p in sim.points()]))
 
     o3d.geometry.PointCloud(points)
@@ -26,4 +26,4 @@ def run_mode(goal, lattice):
         p(i)
         simulation.add_atom(lambda l: random.randrange(l))
 
-    plot_sim(simulation)
\ No newline at end of file
+    plot_sim(simulation, lattice)
